ACTIONet.decomposition package
==============================

Submodules
----------

ACTIONet.decomposition.aa module
--------------------------------

.. automodule:: ACTIONet.decomposition.aa
   :members:
   :undoc-members:
   :show-inheritance:

ACTIONet.decomposition.action module
------------------------------------

.. automodule:: ACTIONet.decomposition.action
   :members:
   :undoc-members:
   :show-inheritance:

ACTIONet.decomposition.actionmr module
--------------------------------------

.. automodule:: ACTIONet.decomposition.actionmr
   :members:
   :undoc-members:
   :show-inheritance:

ACTIONet.decomposition.regression module
----------------------------------------

.. automodule:: ACTIONet.decomposition.regression
   :members:
   :undoc-members:
   :show-inheritance:

ACTIONet.decomposition.spa module
---------------------------------

.. automodule:: ACTIONet.decomposition.spa
   :members:
   :undoc-members:
   :show-inheritance:

ACTIONet.decomposition.utils module
-----------------------------------

.. automodule:: ACTIONet.decomposition.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ACTIONet.decomposition
   :members:
   :undoc-members:
   :show-inheritance:
